Documentation
¶
Overview ¶
Package v1alpha1: Types in this package are instantiated in the other types in k8ssandra-operator, especially Stargate types and Cassandra types. +kubebuilder:object:generate=true
Index ¶
- type CassandraAgentSpec
- type Endpoint
- type McacTelemetrySpec
- type PrometheusTelemetrySpec
- type TelemetrySpec
- func (in *TelemetrySpec) DeepCopy() *TelemetrySpec
- func (in *TelemetrySpec) DeepCopyInto(out *TelemetrySpec)
- func (in *TelemetrySpec) IsMcacEnabled() bool
- func (in *TelemetrySpec) IsPrometheusEnabled() bool
- func (in *TelemetrySpec) IsVectorEnabled() bool
- func (in *TelemetrySpec) MergeWith(clusterTemplate *TelemetrySpec) *TelemetrySpec
- type VectorComponentsSpec
- type VectorSinkSpec
- type VectorSourceSpec
- type VectorSpec
- type VectorTransformSpec
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CassandraAgentSpec ¶ added in v1.6.0
type CassandraAgentSpec struct {
Endpoint *Endpoint `json:"endpoint,omitempty"`
Relabels []promapi.RelabelConfig `json:"relabels,omitempty"`
}
func (*CassandraAgentSpec) DeepCopy ¶ added in v1.6.0
func (in *CassandraAgentSpec) DeepCopy() *CassandraAgentSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CassandraAgentSpec.
func (*CassandraAgentSpec) DeepCopyInto ¶ added in v1.6.0
func (in *CassandraAgentSpec) DeepCopyInto(out *CassandraAgentSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Endpoint ¶ added in v1.6.0
type Endpoint struct {
Address string `json:"address,omitempty"`
Port string `json:"port,omitempty"`
}
func (*Endpoint) DeepCopy ¶ added in v1.6.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Endpoint.
func (*Endpoint) DeepCopyInto ¶ added in v1.6.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type McacTelemetrySpec ¶ added in v1.2.0
type McacTelemetrySpec struct {
// MetricFilters allows passing filters to MCAC in order to reduce the amount of extracted metrics.
// Not setting this field will result in the default filters being used:
// - "deny:org.apache.cassandra.metrics.Table"
// - "deny:org.apache.cassandra.metrics.table"
// - "allow:org.apache.cassandra.metrics.table.live_ss_table_count"
// - "allow:org.apache.cassandra.metrics.Table.LiveSSTableCount"
// - "allow:org.apache.cassandra.metrics.table.live_disk_space_used"
// - "allow:org.apache.cassandra.metrics.table.LiveDiskSpaceUsed"
// - "allow:org.apache.cassandra.metrics.Table.Pending"
// - "allow:org.apache.cassandra.metrics.Table.Memtable"
// - "allow:org.apache.cassandra.metrics.Table.Compaction"
// - "allow:org.apache.cassandra.metrics.table.read"
// - "allow:org.apache.cassandra.metrics.table.write"
// - "allow:org.apache.cassandra.metrics.table.range"
// - "allow:org.apache.cassandra.metrics.table.coordinator"
// - "allow:org.apache.cassandra.metrics.table.dropped_mutations"
// Setting it to an empty list will result in all metrics being extracted.
// +optional
MetricFilters *[]string `json:"metricFilters,omitempty"`
// enabled sets whether MCAC (legacy metrics endpoint) is enabled.
// This is considered true by default.
Enabled *bool `json:"enabled,omitempty"`
}
func (*McacTelemetrySpec) DeepCopy ¶ added in v1.2.0
func (in *McacTelemetrySpec) DeepCopy() *McacTelemetrySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new McacTelemetrySpec.
func (*McacTelemetrySpec) DeepCopyInto ¶ added in v1.2.0
func (in *McacTelemetrySpec) DeepCopyInto(out *McacTelemetrySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrometheusTelemetrySpec ¶
type PrometheusTelemetrySpec struct {
// Enable the creation of Prometheus serviceMonitors for this resource (Cassandra or Stargate).
Enabled *bool `json:"enabled,omitempty"`
// CommonLabels are applied to all serviceMonitors created.
// +optional
CommonLabels map[string]string `json:"commonLabels,omitempty"`
}
func (*PrometheusTelemetrySpec) DeepCopy ¶
func (in *PrometheusTelemetrySpec) DeepCopy() *PrometheusTelemetrySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrometheusTelemetrySpec.
func (*PrometheusTelemetrySpec) DeepCopyInto ¶
func (in *PrometheusTelemetrySpec) DeepCopyInto(out *PrometheusTelemetrySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TelemetrySpec ¶
type TelemetrySpec struct {
Prometheus *PrometheusTelemetrySpec `json:"prometheus,omitempty"`
Mcac *McacTelemetrySpec `json:"mcac,omitempty"`
Vector *VectorSpec `json:"vector,omitempty"`
Cassandra *CassandraAgentSpec `json:"cassandra,omitempty"`
}
func (*TelemetrySpec) DeepCopy ¶
func (in *TelemetrySpec) DeepCopy() *TelemetrySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TelemetrySpec.
func (*TelemetrySpec) DeepCopyInto ¶
func (in *TelemetrySpec) DeepCopyInto(out *TelemetrySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TelemetrySpec) IsMcacEnabled ¶ added in v1.5.0
func (in *TelemetrySpec) IsMcacEnabled() bool
func (*TelemetrySpec) IsPrometheusEnabled ¶ added in v1.5.0
func (in *TelemetrySpec) IsPrometheusEnabled() bool
func (*TelemetrySpec) IsVectorEnabled ¶ added in v1.5.0
func (in *TelemetrySpec) IsVectorEnabled() bool
func (*TelemetrySpec) MergeWith ¶ added in v1.5.0
func (in *TelemetrySpec) MergeWith(clusterTemplate *TelemetrySpec) *TelemetrySpec
MergeWith merges the given cluster-level template into this (DC-level) template.
type VectorComponentsSpec ¶ added in v1.5.0
type VectorComponentsSpec struct {
// Sources is the list of sources to use for the Vector agent.
// +optional
Sources []VectorSourceSpec `json:"sources,omitempty"`
// Sinks is the list of sinks to use for the Vector agent.
// +optional
Sinks []VectorSinkSpec `json:"sinks,omitempty"`
// Transforms is the list of transforms to use for the Vector agent.
// +optional
Transforms []VectorTransformSpec `json:"transforms,omitempty"`
}
func (*VectorComponentsSpec) DeepCopy ¶ added in v1.5.0
func (in *VectorComponentsSpec) DeepCopy() *VectorComponentsSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VectorComponentsSpec.
func (*VectorComponentsSpec) DeepCopyInto ¶ added in v1.5.0
func (in *VectorComponentsSpec) DeepCopyInto(out *VectorComponentsSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VectorSinkSpec ¶ added in v1.5.0
type VectorSinkSpec struct {
// Name is the name of the sink.
Name string `json:"name"`
// Type is the type of the sink.
Type string `json:"type"`
// Inputs is the list of inputs for the transform.
// +optional
Inputs []string `json:"inputs,omitempty"`
// Config is the configuration for the sink.
// +optional
Config string `json:"config,omitempty"`
}
func (*VectorSinkSpec) DeepCopy ¶ added in v1.5.0
func (in *VectorSinkSpec) DeepCopy() *VectorSinkSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VectorSinkSpec.
func (*VectorSinkSpec) DeepCopyInto ¶ added in v1.5.0
func (in *VectorSinkSpec) DeepCopyInto(out *VectorSinkSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VectorSourceSpec ¶ added in v1.5.0
type VectorSourceSpec struct {
// Name is the name of the source.
Name string `json:"name"`
// Type is the type of the source.
Type string `json:"type"`
// Config is the configuration for the source.
// +optional
Config string `json:"config,omitempty"`
}
func (*VectorSourceSpec) DeepCopy ¶ added in v1.5.0
func (in *VectorSourceSpec) DeepCopy() *VectorSourceSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VectorSourceSpec.
func (*VectorSourceSpec) DeepCopyInto ¶ added in v1.5.0
func (in *VectorSourceSpec) DeepCopyInto(out *VectorSourceSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VectorSpec ¶ added in v1.5.0
type VectorSpec struct {
// Enabled enables the Vector agent for this resource (Cassandra, Reaper or Stargate).
// Enabling the vector agent will inject a sidecar container into the pod.
Enabled *bool `json:"enabled,omitempty"`
// Resources is the resource requirements for the Vector agent.
Resources *corev1.ResourceRequirements `json:"resources,omitempty"`
// Image is the name of the Vector image to use. If not set, the default image will be used.
// +optional
// kube:default="timberio/vector:0.26.0-alpine"
Image string `json:"image,omitempty"`
// ScrapeInterval is the interval at which the Vector agent will scrape the metrics endpoint.
// Use values like 30s, 1m, 5m.
// +optional
// kube:default=30s
ScrapeInterval *metav1.Duration `json:"scrapeInterval,omitempty"`
Components *VectorComponentsSpec `json:"components,omitempty"`
}
func (*VectorSpec) DeepCopy ¶ added in v1.5.0
func (in *VectorSpec) DeepCopy() *VectorSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VectorSpec.
func (*VectorSpec) DeepCopyInto ¶ added in v1.5.0
func (in *VectorSpec) DeepCopyInto(out *VectorSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VectorTransformSpec ¶ added in v1.5.0
type VectorTransformSpec struct {
// Name is the name of the transform.
Name string `json:"name"`
// Type is the type of the transform.
Type string `json:"type"`
// Inputs is the list of inputs for the transform.
// +optional
Inputs []string `json:"inputs,omitempty"`
// Config is the configuration for the transform.
// +optional
Config string `json:"config,omitempty"`
}
func (*VectorTransformSpec) DeepCopy ¶ added in v1.5.0
func (in *VectorTransformSpec) DeepCopy() *VectorTransformSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VectorTransformSpec.
func (*VectorTransformSpec) DeepCopyInto ¶ added in v1.5.0
func (in *VectorTransformSpec) DeepCopyInto(out *VectorTransformSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.